==> uos-license-content_1.1.1.orig.tar.xz: uos-license-content-1.1.1/protocol/userexperience-agreement/User-Experience-Program-License-Agreement-CN-zh_CN.md <==
## 统信操作系统用户体验计划许可协议

版本更新日期：[2020]年[12]月[08]日

欢迎参与用户体验计划。用户体验计划（以下简称本计划）是由统信软件技术有限公司（以下简称“统信软件”）开发并运行的、便于改善统信操作系统（包括但不限于统信桌面操作系统和统信服务器操作系统，并以下简称“统信UOS”）的用户体验的网络服务。

利用本服务，可以收集运行统信UOS的计算机的硬件信息、操作系统信息和应用软件信息，并对所收集的信息进行分析，以确定统信UOS可以进一步改善的操作系统功能。

请在参与本计划之前仔细阅读用户体验计划许可协议（以下称为“本协议”）中规定的所有权利和限制。本协议是统信软件与您（自然人、法人或其他组织）之间达成的法律协议。一旦您参与本计划，即表明您同意并接受本协议，并且承认您已阅读和理解了本协议。若您为代表一个实体的个人，一旦您参与本计划即承认您已被授权代表该实体接受本协议。如果您不同意本协议中的任何条款，请勿启动激活本计划。

除非本协议被新协议版本替代，本协议规范适用于任一版本的用户体验计划，以及任何相关的更新，无论交付的方式如何。

 

**1．隐私策略。统信软件制定了严格保护用户隐私数据的隐私策略并非常重视对您的个人信息的保护。用户只有在同时同意了本许可协议和隐私策略之后才可以参与本计划。在参与本计划时，我们将依据本协议和隐私政策的规定从您的设备上收集数据。您可在以下网站上查阅隐私政策的详细信息：**[https://www.uniontech.com/agreement/privacy-cn](https://www.uniontech.com/agreement/privacy-cn)

**2．参与计划。**您可以在统信UOS安装过程中或者在统信UOS的“控制中心--通用--用户体验计划”中，手动选择开启“用户体验计划”，在启动本计划后，统信软件将收集本协议和隐私策略中定义的信息。您可以随时无条件地关闭“用户体验计划”，在关闭本计划之后，统信软件将不再收集您的信息。

**3．知识产权**。本计划中统信软件享有版权的部分受著作权法和其它相关适用法律的保护，并且**统信软件及其关联公司对"统信”商标及标识拥有合法商标权**。（1）您不得去掉本计划上的任何版权标识和商标标识。（2）本计划（包括但不限于本计划中所含的任何图像、照片、动画、录像、录音、音乐、文字和附加程序、色彩、界面设计、版面框架）、随附的文档印刷材料的著作权及其他知识产权，均由统信软件拥有（属于第三方所有之商标及第三方所有之其他权利除外）或统信软件拥有合法使用权。（3）本计划及文档印刷材料享有版权，并受中华人民共和国著作权法、商标法、专利法、反不正当竞争法及国际条约条款的保护。（4）您不可以从本计划中去掉其版权声明。

**4．使用规范。**您在遵守法律及本协议的前提下可依本协议参与本计划。您无权实施包括但不限于下列行为：

(1)发表、传送、传播、储存违反您所在国家法律、危害社会安全、公序良俗的内容，或任何不当的、侮辱诽谤的、淫秽的、暴力的及任何违反使用者所在国家法律法规政策的内容；

(2)发表、传送、传播、储存侵害他人知识产权、商业秘密权等合法权利的内容；

(3)批量发表、传送、传播广告信息及垃圾信息；

(4)发表、传送或散布以其他方式实现传送含有侵犯第三方合法权利（包括但不限于版权、商标权、专利权、商业秘密、隐私权及相关人格权利）的图像、相片、软件或其他资料的文件，除非您已获得权利人充分有效的事先授权； 

(5)任何危害网络安全的行为，包括但不限于：使用未经许可的数据或进入未经许可的服务器/账户；未经允许进入公众网络或者他人操作系统并删除、修改、增加存储信息；未经许可，企图探查、扫描、测试本软件系统或网络的弱点或其它实施破坏网络安全的行为； 企图干涉、破坏本软件系统正常运行，故意传播恶意程序或病毒以及其他破坏干扰正常网络信息服务的行为；伪造TCP/IP数据包名称或部分名称；

(6)其他以任何不合法的方式、为任何不合法的目的、或以任何与本协议不一致的方式参与本计划。

**您若违反上述规定，统信软件有权自行决定采取终止、完全或部分中止、限制您参与本计划的相关功能并保留追究上述行为的一切权利。**

**5．免责说明**。本计划不享受任何其他形式的售后担保。在适用法律允许的最大限度内，统信软件不提供任何明示、默示或法定的保证、保障或条件，包括但不限于有关适销性、针对特定目的的适用性和不侵权的默示保证。

**您应该经常对您的文件做出备份。您须自行承担使用该软件的风险。对因参与本计划所产生的损害及风险，包括但不限于直接或间接的个人损害、商业盈利的丧失、贸易中断、商业信息的丢失或任何其它经济损失，统信软件不承担任何责任。对于因电信系统或互联网网络故障、配套系统故障问题或其它任何不可抗力原因（包括黑客攻击行为）而产生的损失，统信软件不承担任何责任。**

**6．许可终止**。（1）如您未遵守本协议的各项条款和条件，统信软件可终止本协议。（2）通过向您提供本计划的任何替换版本或修改版本或升级版本的一份取代协议，并规定您使用这类替换版本或修改版本或升级版本的条件是您接受这类取代协议，统信软件可以终止本协议。

**7．管辖和法律适用**。本协议的订立、执行和解释及争议的解决均应适用中华人民共和国法律。**如您与统信软件就本协议内容或其执行发生任何争议，双方应进行友好协商；协商不成时，任何一方均可向统信软件所在地有管辖权的人民法院提起诉讼**。

**8．解释以及修改。**统信软件在不违背法律规定所允许的最大范围内对本协议拥有解释权与修改权。统信软件有权随时根据有关法律、法规的变化以及公司经营状况和经营策略的调整等修改本协议。修改后的协议会在随附于新版统信UOS中在您使用前阅读和选择接受。当发生有关争议时，本协议终止，以最新的协议文本为准。如果您不同意协议变更的内容，您可以不启用本计划。如果您继续参与本计划，则视为您接受本协议的变更。

**9．联系我们**。如果您对本协议有任何疑问或者希望从统信软件获得任何信息，请按下列联系方式与统信软件直接联系：support@uniontech.com。

==> uos-license-content_1.1.8.orig.tar.xz: uos-license-content-1.1.8/protocol/userexperience-agreement/User-Experience-Program-License-Agreement-CN-zh_CN.md <==
## 统信操作系统用户体验计划许可协议

版本更新日期：[2021]年[04]月[01]日

欢迎参与用户体验计划。用户体验计划（以下简称“本计划”）是由统信软件技术有限公司（以下简称“统信软件”）开发并运行的、便于改善统信操作系统（包括但不限于统信桌面操作系统和统信服务器操作系统，并以下简称“统信UOS”）的用户体验的网络服务。

利用本服务，可以收集运行统信UOS的计算机的硬件信息、操作系统信息和应用软件信息，并对所收集的信息进行分析，以确定统信UOS可以进一步改善的操作系统功能。

请在参与本计划之前仔细阅读用户体验计划许可协议（以下称为“本协议”）中规定的所有权利和限制。本协议是统信软件与您（自然人、法人或其他组织）之间达成的法律协议。一旦您参与本计划，即表明您同意并接受本协议，并且承认您已阅读和理解了本协议。若您为代表一个实体的个人，一旦您参与本计划即承认您已被授权代表该实体接受本协议。如果您不同意本协议中的任何条款，请勿启动激活本计划。

除非本协议被新协议版本替代，本协议规范适用于任一版本的用户体验计划，以及任何相关的更新，无论交付的方式如何。

 

**1．隐私策略。统信软件制定了严格保护用户隐私数据的隐私策略并非常重视对您的个人信息的保护。用户只有在同时同意了本许可协议和隐私策略之后才可以参与本计划。在参与本计划时，我们将依据本协议和隐私政策的规定从您的设备上收集数据。您可在以下网站上查阅隐私政策的详细信息：**[https://www.uniontech.com/agreement/privacy-cn](https://www.uniontech.com/agreement/privacy-cn)

2．**参与计划**。您可以在统信UOS安装过程中或者在统信UOS的“控制中心--通用--用户体验计划”中，手动选择开启“用户体验计划”，在启动本计划后，统信软件将收集本协议和隐私策略中定义的信息。您可以随时无条件地关闭“用户体验计划”。

**3．知识产权**。本计划中统信软件享有著作权的部分受著作权法和其它相关适用法律的保护，并且**统信软件及其关联公司对"统信”和“统信UOS”商标及标识拥有合法商标权**。（1）您不得去掉本计划上的任何版权标识和商标标识。（2）本计划（包括但不限于本计划中所含的任何图像、照片、动画、录像、录音、音乐、文字和附加程序、色彩、界面设计、版面框架）、随附的文档印刷材料的著作权及其他知识产权，均由统信软件拥有（属于第三方所有之商标及第三方所有之其他权利除外）或统信软件拥有合法使用权。（3）本计划及文档印刷材料享有版权，并受中华人民共和国著作权法、商标法、专利法、反不正当竞争法及国际条约条款的保护。（4）您不可以从本计划中去掉其版权声明。

4．**使用规范**。您在遵守法律及本协议的前提下可依本协议参与本计划。您无权实施包括但不限于下列行为：

(1)发表、传送、传播、储存违反您所在国家法律、危害社会安全、公序良俗的内容，或任何不当的、侮辱诽谤的、淫秽的、暴力的及任何违反使用者所在国家法律法规政策的内容；

(2)发表、传送、传播、储存侵害他人知识产权、商业秘密权等合法权利的内容；

(3)批量发表、传送、传播广告信息及垃圾信息；

(4)发表、传送或散布以其他方式实现传送含有侵犯第三方合法权利（包括但不限于版权、商标权、专利权、商业秘密、隐私权及相关人格权利）的图像、相片、软件或其他资料的文件，除非您已获得权利人充分有效的事先授权； 

(5)任何危害网络安全的行为，包括但不限于：使用未经许可的数据或进入未经许可的服务器/账户；未经允许进入公众网络或者他人操作系统并删除、修改、增加存储信息；未经许可，企图探查、扫描、测试本软件系统或网络的弱点或其它实施破坏网络安全的行为； 企图干涉、破坏本软件系统正常运行，故意传播恶意程序或病毒以及其他破坏干扰正常网络信息服务的行为；伪造TCP/IP数据包名称或部分名称；

(6)其他以任何不合法的方式、为任何不合法的目的、或以任何与本协议不一致的方式参与本计划。

**您若违反上述规定，统信软件有权自行决定采取终止、完全或部分中止、限制您参与本计划的相关功能并保留追究上述行为的一切权利。**

**5．免责说明**。本计划不享受任何其他形式的售后担保。在适用法律允许的最大限度内，统信软件不提供任何明示、默示或法定的保证、保障或条件，包括但不限于有关适销性、针对特定目的的适用性和不侵权的默示保证。

**您应该经常对您的文件做出备份。您须自行承担使用该软件的风险。对因参与本计划所产生的损害及风险，包括但不限于直接或间接的个人损害、商业盈利的丧失、贸易中断、商业信息的丢失或任何其它经济损失，统信软件不承担任何责任。对于因电信系统或互联网网络故障、配套系统故障问题或其它任何不可抗力原因（包括黑客攻击行为）而产生的损失，统信软件不承担任何责任。**

**6．许可终止**。（1）如您未遵守本协议的各项条款和条件，统信软件可终止本协议。（2）通过向您提供本计划的任何替换版本或修改版本或升级版本的一份取代协议，并规定您使用这类替换版本或修改版本或升级版本的条件是您接受这类取代协议，统信软件可以终止本协议。

**7．管辖和法律适用**。本协议的订立、执行和解释及争议的解决均应适用中华人民共和国（不包含港澳台地区）法律。**如您与统信软件就本协议内容或其执行发生任何争议，双方应进行友好协商；协商不成时，任何一方均可向统信软件所在地有管辖权的人民法院提起诉讼**。

8．**解释以及修改**。统信软件在不违背法律规定所允许的最大范围内对本协议拥有解释权与修改权。统信软件有权随时根据有关法律、法规的变化以及公司经营状况和经营策略的调整等修改本协议。修改后的协议会在随附于新版统信UOS中在您使用前阅读和选择接受。当发生有关争议时，本协议终止，以最新的协议文本为准。如果您不同意协议变更的内容，您可以不启用本计划。如果您继续参与本计划，则视为您接受本协议的变更。

**9．联系我们**。如果您对本协议有任何疑问或者希望从统信软件获得任何信息，请按下列联系方式与统信软件直接联系：support@uniontech.com。
